@@ -2,7 +2,7 @@ package DBIx::SchemaChecksum;
 
 use 5.010;
 use Moose;
-use version; our $VERSION = version->new('0.08');
+use version; our $VERSION = version->new('0.09');
 
 use DBI;
 use Digest::SHA1;
@@ -184,7 +184,16 @@ sub schemadump {
             }
 
 			foreach my $col ( @{ $data{columns} } ) {
-				$col->{TYPE_NAME} =~ s/^(?:.+\.)?(.+)$/$1/g;
+                #  strip schema dependent type definition
+                $col->{TYPE_NAME} =~ s/^(?:.+\.)?(.+)$/$1/g;
+
+                # remove types from autoincrement
+                if ($col->{COLUMN_DEF} && $col->{COLUMN_DEF} =~ /nextval/ ) {
+                    $col->{COLUMN_DEF}=~m{'([\w\.\-_]+)'};
+                    if ($1) {
+                        $col->{COLUMN_DEF}='nextval:'.$1;
+                    }
+                }
 			}
 
             $relevants{$table} = \%data;
